# winget submission helper for lore-book 1.3.1

Generated: 2026-03-26

## Package metadata

- PackageIdentifier: CptPlastic.LoreBook
- PackageVersion: 1.3.1
- Publisher: CptPlastic
- PackageName: lore-book
- License: FSL-1.1-MIT
- InstallerUrl: https://files.pythonhosted.org/packages/source/l/lore-book/lore-book-1.3.1.tar.gz
- InstallerSha256: ba182d53d62373205257b13b6557aff4b742d02a26234e16aea32ebe5ea6f0b5

## Notes

`lore-book` is a Python CLI package. A direct winget installer is not auto-published from this repo.
Use this file as the source of truth for opening/updating a PR in `microsoft/winget-pkgs`.

## Recommended submission flow

1. Install wingetcreate.
2. Create or update a manifest for `CptPlastic.LoreBook` using the URL/hash above.
3. Open a PR in `microsoft/winget-pkgs`.

Reference repository: https://github.com/CptPlastic/lore-book
